<a id="aea.helpers.protocols"></a>

# aea.helpers.protocols

Protocol helpers.

<a id="aea.helpers.protocols.get_protocol_specification_from_readme"></a>

#### get`_`protocol`_`specification`_`from`_`readme

```python
def get_protocol_specification_from_readme(package_path: Path) -> str
```

Get the protocol specification from the package README.

<a id="aea.helpers.protocols.get_protocol_specification_id_from_specification"></a>

#### get`_`protocol`_`specification`_`id`_`from`_`specification

```python
def get_protocol_specification_id_from_specification(
        specification: str) -> str
```

Get the protocol specification id from the protocol specification.

